# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: client/admin/v1_12/enterprise/enterprise.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='client/admin/v1_12/enterprise/enterprise.proto',
  package='enterprise_1_12',
  syntax='proto3',
  serialized_options=b'Z@github.com/pachyderm/pachyderm/src/client/admin/v1_12/enterprise',
  serialized_pb=b'\n.client/admin/v1_12/enterprise/enterprise.proto\x12\x0f\x65nterprise_1_12\x1a\x1fgoogle/protobuf/timestamp.proto\"X\n\x10\x45nterpriseRecord\x12\x17\n\x0f\x61\x63tivation_code\x18\x01 \x01(\t\x12+\n\x07\x65xpires\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"8\n\tTokenInfo\x12+\n\x07\x65xpires\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"W\n\x0f\x41\x63tivateRequest\x12\x17\n\x0f\x61\x63tivation_code\x18\x01 \x01(\t\x12+\n\x07\x65xpires\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"<\n\x10\x41\x63tivateResponse\x12(\n\x04info\x18\x01 \x01(\x0b\x32\x1a.enterprise_1_12.TokenInfo\"\x11\n\x0fGetStateRequest\"|\n\x10GetStateResponse\x12%\n\x05state\x18\x01 \x01(\x0e\x32\x16.enterprise_1_12.State\x12(\n\x04info\x18\x02 \x01(\x0b\x32\x1a.enterprise_1_12.TokenInfo\x12\x17\n\x0f\x61\x63tivation_code\x18\x03 \x01(\t\"\x13\n\x11\x44\x65\x61\x63tivateRequest\"\x14\n\x12\x44\x65\x61\x63tivateResponse**\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0b\n\x07\x45XPIRED\x10\x02\x32\x84\x02\n\x03\x41PI\x12Q\n\x08\x41\x63tivate\x12 .enterprise_1_12.ActivateRequest\x1a!.enterprise_1_12.ActivateResponse\"\x00\x12Q\n\x08GetState\x12 .enterprise_1_12.GetStateRequest\x1a!.enterprise_1_12.GetStateResponse\"\x00\x12W\n\nDeactivate\x12\".enterprise_1_12.DeactivateRequest\x1a#.enterprise_1_12.DeactivateResponse\"\x00\x42\x42Z@github.com/pachyderm/pachyderm/src/client/admin/v1_12/enterpriseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='enterprise_1_12.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXPIRED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=587,
  serialized_end=629,
)
_sym_db.RegisterEnumDescriptor(_STATE)

State = enum_type_wrapper.EnumTypeWrapper(_STATE)
NONE = 0
ACTIVE = 1
EXPIRED = 2



_ENTERPRISERECORD = _descriptor.Descriptor(
  name='EnterpriseRecord',
  full_name='enterprise_1_12.EnterpriseRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='activation_code', full_name='enterprise_1_12.EnterpriseRecord.activation_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expires', full_name='enterprise_1_12.EnterpriseRecord.expires', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=188,
)


_TOKENINFO = _descriptor.Descriptor(
  name='TokenInfo',
  full_name='enterprise_1_12.TokenInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expires', full_name='enterprise_1_12.TokenInfo.expires', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=246,
)


_ACTIVATEREQUEST = _descriptor.Descriptor(
  name='ActivateRequest',
  full_name='enterprise_1_12.ActivateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='activation_code', full_name='enterprise_1_12.ActivateRequest.activation_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expires', full_name='enterprise_1_12.ActivateRequest.expires', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=335,
)


_ACTIVATERESPONSE = _descriptor.Descriptor(
  name='ActivateResponse',
  full_name='enterprise_1_12.ActivateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='enterprise_1_12.ActivateResponse.info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=397,
)


_GETSTATEREQUEST = _descriptor.Descriptor(
  name='GetStateRequest',
  full_name='enterprise_1_12.GetStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=416,
)


_GETSTATERESPONSE = _descriptor.Descriptor(
  name='GetStateResponse',
  full_name='enterprise_1_12.GetStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='enterprise_1_12.GetStateResponse.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='enterprise_1_12.GetStateResponse.info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activation_code', full_name='enterprise_1_12.GetStateResponse.activation_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=418,
  serialized_end=542,
)


_DEACTIVATEREQUEST = _descriptor.Descriptor(
  name='DeactivateRequest',
  full_name='enterprise_1_12.DeactivateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=544,
  serialized_end=563,
)


_DEACTIVATERESPONSE = _descriptor.Descriptor(
  name='DeactivateResponse',
  full_name='enterprise_1_12.DeactivateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=565,
  serialized_end=585,
)

_ENTERPRISERECORD.fields_by_name['expires'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TOKENINFO.fields_by_name['expires'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVATEREQUEST.fields_by_name['expires'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ACTIVATERESPONSE.fields_by_name['info'].message_type = _TOKENINFO
_GETSTATERESPONSE.fields_by_name['state'].enum_type = _STATE
_GETSTATERESPONSE.fields_by_name['info'].message_type = _TOKENINFO
DESCRIPTOR.message_types_by_name['EnterpriseRecord'] = _ENTERPRISERECORD
DESCRIPTOR.message_types_by_name['TokenInfo'] = _TOKENINFO
DESCRIPTOR.message_types_by_name['ActivateRequest'] = _ACTIVATEREQUEST
DESCRIPTOR.message_types_by_name['ActivateResponse'] = _ACTIVATERESPONSE
DESCRIPTOR.message_types_by_name['GetStateRequest'] = _GETSTATEREQUEST
DESCRIPTOR.message_types_by_name['GetStateResponse'] = _GETSTATERESPONSE
DESCRIPTOR.message_types_by_name['DeactivateRequest'] = _DEACTIVATEREQUEST
DESCRIPTOR.message_types_by_name['DeactivateResponse'] = _DEACTIVATERESPONSE
DESCRIPTOR.enum_types_by_name['State'] = _STATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EnterpriseRecord = _reflection.GeneratedProtocolMessageType('EnterpriseRecord', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPRISERECORD,
  '__module__' : 'client.admin.v1_12.enterprise.enterprise_pb2'
  # @@protoc_insertion_point(class_scope:enterprise_1_12.EnterpriseRecord)
  })
_sym_db.RegisterMessage(EnterpriseRecord)

TokenInfo = _reflection.GeneratedProtocolMessageType('TokenInfo', (_message.Message,), {
  'DESCRIPTOR' : _TOKENINFO,
  '__module__' : 'client.admin.v1_12.enterprise.enterprise_pb2'
  # @@protoc_insertion_point(class_scope:enterprise_1_12.TokenInfo)
  })
_sym_db.RegisterMessage(TokenInfo)

ActivateRequest = _reflection.GeneratedProtocolMessageType('ActivateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEREQUEST,
  '__module__' : 'client.admin.v1_12.enterprise.enterprise_pb2'
  # @@protoc_insertion_point(class_scope:enterprise_1_12.ActivateRequest)
  })
_sym_db.RegisterMessage(ActivateRequest)

ActivateResponse = _reflection.GeneratedProtocolMessageType('ActivateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATERESPONSE,
  '__module__' : 'client.admin.v1_12.enterprise.enterprise_pb2'
  # @@protoc_insertion_point(class_scope:enterprise_1_12.ActivateResponse)
  })
_sym_db.RegisterMessage(ActivateResponse)

GetStateRequest = _reflection.GeneratedProtocolMessageType('GetStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATEREQUEST,
  '__module__' : 'client.admin.v1_12.enterprise.enterprise_pb2'
  # @@protoc_insertion_point(class_scope:enterprise_1_12.GetStateRequest)
  })
_sym_db.RegisterMessage(GetStateRequest)

GetStateResponse = _reflection.GeneratedProtocolMessageType('GetStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATERESPONSE,
  '__module__' : 'client.admin.v1_12.enterprise.enterprise_pb2'
  # @@protoc_insertion_point(class_scope:enterprise_1_12.GetStateResponse)
  })
_sym_db.RegisterMessage(GetStateResponse)

DeactivateRequest = _reflection.GeneratedProtocolMessageType('DeactivateRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEACTIVATEREQUEST,
  '__module__' : 'client.admin.v1_12.enterprise.enterprise_pb2'
  # @@protoc_insertion_point(class_scope:enterprise_1_12.DeactivateRequest)
  })
_sym_db.RegisterMessage(DeactivateRequest)

DeactivateResponse = _reflection.GeneratedProtocolMessageType('DeactivateResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEACTIVATERESPONSE,
  '__module__' : 'client.admin.v1_12.enterprise.enterprise_pb2'
  # @@protoc_insertion_point(class_scope:enterprise_1_12.DeactivateResponse)
  })
_sym_db.RegisterMessage(DeactivateResponse)


DESCRIPTOR._options = None

_API = _descriptor.ServiceDescriptor(
  name='API',
  full_name='enterprise_1_12.API',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=632,
  serialized_end=892,
  methods=[
  _descriptor.MethodDescriptor(
    name='Activate',
    full_name='enterprise_1_12.API.Activate',
    index=0,
    containing_service=None,
    input_type=_ACTIVATEREQUEST,
    output_type=_ACTIVATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetState',
    full_name='enterprise_1_12.API.GetState',
    index=1,
    containing_service=None,
    input_type=_GETSTATEREQUEST,
    output_type=_GETSTATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Deactivate',
    full_name='enterprise_1_12.API.Deactivate',
    index=2,
    containing_service=None,
    input_type=_DEACTIVATEREQUEST,
    output_type=_DEACTIVATERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_API)

DESCRIPTOR.services_by_name['API'] = _API

# @@protoc_insertion_point(module_scope)
