# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: client/admin/v1_10/auth/auth.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='client/admin/v1_10/auth/auth.proto',
  package='auth_1_10',
  syntax='proto3',
  serialized_options=b'Z:github.com/pachyderm/pachyderm/src/client/admin/v1_10/auth',
  serialized_pb=b'\n\"client/admin/v1_10/auth/auth.proto\x12\tauth_1_10\x1a\x1fgoogle/protobuf/timestamp.proto\"8\n\x0f\x41\x63tivateRequest\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x14\n\x0cgithub_token\x18\x01 \x01(\t\"&\n\x10\x41\x63tivateResponse\x12\x12\n\npach_token\x18\x01 \x01(\t\"\x13\n\x11\x44\x65\x61\x63tivateRequest\"\x14\n\x12\x44\x65\x61\x63tivateResponse\"\xfa\x01\n\nIDProvider\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12/\n\x04saml\x18\x03 \x01(\x0b\x32!.auth_1_10.IDProvider.SAMLOptions\x12\x33\n\x06github\x18\x04 \x01(\x0b\x32#.auth_1_10.IDProvider.GitHubOptions\x1aR\n\x0bSAMLOptions\x12\x14\n\x0cmetadata_url\x18\x01 \x01(\t\x12\x14\n\x0cmetadata_xml\x18\x02 \x01(\x0c\x12\x17\n\x0fgroup_attribute\x18\x03 \x01(\t\x1a\x0f\n\rGitHubOptions\"\x9a\x02\n\nAuthConfig\x12\x1b\n\x13live_config_version\x18\x01 \x01(\x03\x12+\n\x0cid_providers\x18\x02 \x03(\x0b\x32\x15.auth_1_10.IDProvider\x12\x42\n\x10saml_svc_options\x18\x03 \x01(\x0b\x32(.auth_1_10.AuthConfig.SAMLServiceOptions\x1a~\n\x12SAMLServiceOptions\x12\x0f\n\x07\x61\x63s_url\x18\x01 \x01(\t\x12\x14\n\x0cmetadata_url\x18\x02 \x01(\t\x12\x10\n\x08\x64\x61sh_url\x18\x03 \x01(\t\x12\x18\n\x10session_duration\x18\x04 \x01(\t\x12\x15\n\rdebug_logging\x18\x05 \x01(\x08\"\x19\n\x17GetConfigurationRequest\"H\n\x18GetConfigurationResponse\x12,\n\rconfiguration\x18\x01 \x01(\x0b\x32\x15.auth_1_10.AuthConfig\"G\n\x17SetConfigurationRequest\x12,\n\rconfiguration\x18\x01 \x01(\x0b\x32\x15.auth_1_10.AuthConfig\"\x1a\n\x18SetConfigurationResponse\"\x12\n\x10GetAdminsRequest\"#\n\x11GetAdminsResponse\x12\x0e\n\x06\x61\x64mins\x18\x01 \x03(\t\"2\n\x13ModifyAdminsRequest\x12\x0b\n\x03\x61\x64\x64\x18\x01 \x03(\t\x12\x0e\n\x06remove\x18\x02 \x03(\t\"\x16\n\x14ModifyAdminsResponse\"R\n\x07OTPInfo\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x36\n\x12session_expiration\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x8b\x01\n\tTokenInfo\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x30\n\x06source\x18\x02 \x01(\x0e\x32 .auth_1_10.TokenInfo.TokenSource\";\n\x0bTokenSource\x12\x0b\n\x07INVALID\x10\x00\x12\x10\n\x0c\x41UTHENTICATE\x10\x01\x12\r\n\tGET_TOKEN\x10\x02\"F\n\x13\x41uthenticateRequest\x12\x14\n\x0cgithub_token\x18\x01 \x01(\t\x12\x19\n\x11one_time_password\x18\x02 \x01(\t\"*\n\x14\x41uthenticateResponse\x12\x12\n\npach_token\x18\x01 \x01(\t\"\x0f\n\rWhoAmIRequest\"A\n\x0eWhoAmIResponse\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08is_admin\x18\x02 \x01(\x08\x12\x0b\n\x03ttl\x18\x03 \x01(\x03\"u\n\x03\x41\x43L\x12,\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1b.auth_1_10.ACL.EntriesEntry\x1a@\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0e\x32\x10.auth_1_10.Scope:\x02\x38\x01\"m\n\x05Users\x12\x32\n\tusernames\x18\x01 \x03(\x0b\x32\x1f.auth_1_10.Users.UsernamesEntry\x1a\x30\n\x0eUsernamesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"f\n\x06Groups\x12-\n\x06groups\x18\x01 \x03(\x0b\x32\x1d.auth_1_10.Groups.GroupsEntry\x1a-\n\x0bGroupsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"A\n\x10\x41uthorizeRequest\x12\x0c\n\x04repo\x18\x01 \x01(\t\x12\x1f\n\x05scope\x18\x02 \x01(\x0e\x32\x10.auth_1_10.Scope\"\'\n\x11\x41uthorizeResponse\x12\x12\n\nauthorized\x18\x01 \x01(\x08\"2\n\x0fGetScopeRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\r\n\x05repos\x18\x02 \x03(\t\"4\n\x10GetScopeResponse\x12 \n\x06scopes\x18\x01 \x03(\x0e\x32\x10.auth_1_10.Scope\"R\n\x0fSetScopeRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0c\n\x04repo\x18\x02 \x01(\t\x12\x1f\n\x05scope\x18\x03 \x01(\x0e\x32\x10.auth_1_10.Scope\"\x12\n\x10SetScopeResponse\"\x1d\n\rGetACLRequest\x12\x0c\n\x04repo\x18\x01 \x01(\t\"=\n\x08\x41\x43LEntry\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x1f\n\x05scope\x18\x02 \x01(\x0e\x32\x10.auth_1_10.Scope\"b\n\x0eGetACLResponse\x12$\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x13.auth_1_10.ACLEntry\x12*\n\rrobot_entries\x18\x02 \x03(\x0b\x32\x13.auth_1_10.ACLEntry\"C\n\rSetACLRequest\x12\x0c\n\x04repo\x18\x01 \x01(\t\x12$\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x13.auth_1_10.ACLEntry\"\x10\n\x0eSetACLResponse\"3\n\x13GetAuthTokenRequest\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x0b\n\x03ttl\x18\x02 \x01(\x03\"6\n\x14GetAuthTokenResponse\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\r\n\x05token\x18\x01 \x01(\t\"4\n\x16\x45xtendAuthTokenRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0b\n\x03ttl\x18\x02 \x01(\x03\"\x19\n\x17\x45xtendAuthTokenResponse\"\'\n\x16RevokeAuthTokenRequest\x12\r\n\x05token\x18\x01 \x01(\t\"\x19\n\x17RevokeAuthTokenResponse\";\n\x17SetGroupsForUserRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0e\n\x06groups\x18\x02 \x03(\t\"\x1a\n\x18SetGroupsForUserResponse\"B\n\x14ModifyMembersRequest\x12\r\n\x05group\x18\x01 \x01(\t\x12\x0b\n\x03\x61\x64\x64\x18\x02 \x03(\t\x12\x0e\n\x06remove\x18\x03 \x03(\t\"\x17\n\x15ModifyMembersResponse\"$\n\x10GetGroupsRequest\x12\x10\n\x08username\x18\x01 \x01(\t\"#\n\x11GetGroupsResponse\x12\x0e\n\x06groups\x18\x01 \x03(\t\" \n\x0fGetUsersRequest\x12\r\n\x05group\x18\x01 \x01(\t\"%\n\x10GetUsersResponse\x12\x11\n\tusernames\x18\x01 \x03(\t\"9\n\x19GetOneTimePasswordRequest\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x0b\n\x03ttl\x18\x02 \x01(\x03\"^\n\x1aGetOneTimePasswordResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x32\n\x0eotp_expiration\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp*4\n\x05Scope\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06READER\x10\x01\x12\n\n\x06WRITER\x10\x02\x12\t\n\x05OWNER\x10\x03\x32\x98\r\n\x03\x41PI\x12\x45\n\x08\x41\x63tivate\x12\x1a.auth_1_10.ActivateRequest\x1a\x1b.auth_1_10.ActivateResponse\"\x00\x12K\n\nDeactivate\x12\x1c.auth_1_10.DeactivateRequest\x1a\x1d.auth_1_10.DeactivateResponse\"\x00\x12]\n\x10GetConfiguration\x12\".auth_1_10.GetConfigurationRequest\x1a#.auth_1_10.GetConfigurationResponse\"\x00\x12]\n\x10SetConfiguration\x12\".auth_1_10.SetConfigurationRequest\x1a#.auth_1_10.SetConfigurationResponse\"\x00\x12H\n\tGetAdmins\x12\x1b.auth_1_10.GetAdminsRequest\x1a\x1c.auth_1_10.GetAdminsResponse\"\x00\x12Q\n\x0cModifyAdmins\x12\x1e.auth_1_10.ModifyAdminsRequest\x1a\x1f.auth_1_10.ModifyAdminsResponse\"\x00\x12Q\n\x0c\x41uthenticate\x12\x1e.auth_1_10.AuthenticateRequest\x1a\x1f.auth_1_10.AuthenticateResponse\"\x00\x12H\n\tAuthorize\x12\x1b.auth_1_10.AuthorizeRequest\x1a\x1c.auth_1_10.AuthorizeResponse\"\x00\x12?\n\x06WhoAmI\x12\x18.auth_1_10.WhoAmIRequest\x1a\x19.auth_1_10.WhoAmIResponse\"\x00\x12\x45\n\x08GetScope\x12\x1a.auth_1_10.GetScopeRequest\x1a\x1b.auth_1_10.GetScopeResponse\"\x00\x12\x45\n\x08SetScope\x12\x1a.auth_1_10.SetScopeRequest\x1a\x1b.auth_1_10.SetScopeResponse\"\x00\x12?\n\x06GetACL\x12\x18.auth_1_10.GetACLRequest\x1a\x19.auth_1_10.GetACLResponse\"\x00\x12?\n\x06SetACL\x12\x18.auth_1_10.SetACLRequest\x1a\x19.auth_1_10.SetACLResponse\"\x00\x12Q\n\x0cGetAuthToken\x12\x1e.auth_1_10.GetAuthTokenRequest\x1a\x1f.auth_1_10.GetAuthTokenResponse\"\x00\x12Z\n\x0f\x45xtendAuthToken\x12!.auth_1_10.ExtendAuthTokenRequest\x1a\".auth_1_10.ExtendAuthTokenResponse\"\x00\x12Z\n\x0fRevokeAuthToken\x12!.auth_1_10.RevokeAuthTokenRequest\x1a\".auth_1_10.RevokeAuthTokenResponse\"\x00\x12]\n\x10SetGroupsForUser\x12\".auth_1_10.SetGroupsForUserRequest\x1a#.auth_1_10.SetGroupsForUserResponse\"\x00\x12T\n\rModifyMembers\x12\x1f.auth_1_10.ModifyMembersRequest\x1a .auth_1_10.ModifyMembersResponse\"\x00\x12H\n\tGetGroups\x12\x1b.auth_1_10.GetGroupsRequest\x1a\x1c.auth_1_10.GetGroupsResponse\"\x00\x12\x45\n\x08GetUsers\x12\x1a.auth_1_10.GetUsersRequest\x1a\x1b.auth_1_10.GetUsersResponse\"\x00\x12\x63\n\x12GetOneTimePassword\x12$.auth_1_10.GetOneTimePasswordRequest\x1a%.auth_1_10.GetOneTimePasswordResponse\"\x00\x42<Z:github.com/pachyderm/pachyderm/src/client/admin/v1_10/authb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_SCOPE = _descriptor.EnumDescriptor(
  name='Scope',
  full_name='auth_1_10.Scope',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READER', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WRITER', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OWNER', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3198,
  serialized_end=3250,
)
_sym_db.RegisterEnumDescriptor(_SCOPE)

Scope = enum_type_wrapper.EnumTypeWrapper(_SCOPE)
NONE = 0
READER = 1
WRITER = 2
OWNER = 3


_TOKENINFO_TOKENSOURCE = _descriptor.EnumDescriptor(
  name='TokenSource',
  full_name='auth_1_10.TokenInfo.TokenSource',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTHENTICATE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET_TOKEN', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1261,
  serialized_end=1320,
)
_sym_db.RegisterEnumDescriptor(_TOKENINFO_TOKENSOURCE)


_ACTIVATEREQUEST = _descriptor.Descriptor(
  name='ActivateRequest',
  full_name='auth_1_10.ActivateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='auth_1_10.ActivateRequest.subject', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='github_token', full_name='auth_1_10.ActivateRequest.github_token', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=138,
)


_ACTIVATERESPONSE = _descriptor.Descriptor(
  name='ActivateResponse',
  full_name='auth_1_10.ActivateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pach_token', full_name='auth_1_10.ActivateResponse.pach_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=178,
)


_DEACTIVATEREQUEST = _descriptor.Descriptor(
  name='DeactivateRequest',
  full_name='auth_1_10.DeactivateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=180,
  serialized_end=199,
)


_DEACTIVATERESPONSE = _descriptor.Descriptor(
  name='DeactivateResponse',
  full_name='auth_1_10.DeactivateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=221,
)


_IDPROVIDER_SAMLOPTIONS = _descriptor.Descriptor(
  name='SAMLOptions',
  full_name='auth_1_10.IDProvider.SAMLOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata_url', full_name='auth_1_10.IDProvider.SAMLOptions.metadata_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata_xml', full_name='auth_1_10.IDProvider.SAMLOptions.metadata_xml', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_attribute', full_name='auth_1_10.IDProvider.SAMLOptions.group_attribute', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=375,
  serialized_end=457,
)

_IDPROVIDER_GITHUBOPTIONS = _descriptor.Descriptor(
  name='GitHubOptions',
  full_name='auth_1_10.IDProvider.GitHubOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=459,
  serialized_end=474,
)

_IDPROVIDER = _descriptor.Descriptor(
  name='IDProvider',
  full_name='auth_1_10.IDProvider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='auth_1_10.IDProvider.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='auth_1_10.IDProvider.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='saml', full_name='auth_1_10.IDProvider.saml', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='github', full_name='auth_1_10.IDProvider.github', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_IDPROVIDER_SAMLOPTIONS, _IDPROVIDER_GITHUBOPTIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=474,
)


_AUTHCONFIG_SAMLSERVICEOPTIONS = _descriptor.Descriptor(
  name='SAMLServiceOptions',
  full_name='auth_1_10.AuthConfig.SAMLServiceOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='acs_url', full_name='auth_1_10.AuthConfig.SAMLServiceOptions.acs_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata_url', full_name='auth_1_10.AuthConfig.SAMLServiceOptions.metadata_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dash_url', full_name='auth_1_10.AuthConfig.SAMLServiceOptions.dash_url', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_duration', full_name='auth_1_10.AuthConfig.SAMLServiceOptions.session_duration', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='debug_logging', full_name='auth_1_10.AuthConfig.SAMLServiceOptions.debug_logging', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=633,
  serialized_end=759,
)

_AUTHCONFIG = _descriptor.Descriptor(
  name='AuthConfig',
  full_name='auth_1_10.AuthConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='live_config_version', full_name='auth_1_10.AuthConfig.live_config_version', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_providers', full_name='auth_1_10.AuthConfig.id_providers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='saml_svc_options', full_name='auth_1_10.AuthConfig.saml_svc_options', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_AUTHCONFIG_SAMLSERVICEOPTIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=477,
  serialized_end=759,
)


_GETCONFIGURATIONREQUEST = _descriptor.Descriptor(
  name='GetConfigurationRequest',
  full_name='auth_1_10.GetConfigurationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=761,
  serialized_end=786,
)


_GETCONFIGURATIONRESPONSE = _descriptor.Descriptor(
  name='GetConfigurationResponse',
  full_name='auth_1_10.GetConfigurationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='configuration', full_name='auth_1_10.GetConfigurationResponse.configuration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=788,
  serialized_end=860,
)


_SETCONFIGURATIONREQUEST = _descriptor.Descriptor(
  name='SetConfigurationRequest',
  full_name='auth_1_10.SetConfigurationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='configuration', full_name='auth_1_10.SetConfigurationRequest.configuration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=862,
  serialized_end=933,
)


_SETCONFIGURATIONRESPONSE = _descriptor.Descriptor(
  name='SetConfigurationResponse',
  full_name='auth_1_10.SetConfigurationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=935,
  serialized_end=961,
)


_GETADMINSREQUEST = _descriptor.Descriptor(
  name='GetAdminsRequest',
  full_name='auth_1_10.GetAdminsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=981,
)


_GETADMINSRESPONSE = _descriptor.Descriptor(
  name='GetAdminsResponse',
  full_name='auth_1_10.GetAdminsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='admins', full_name='auth_1_10.GetAdminsResponse.admins', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=983,
  serialized_end=1018,
)


_MODIFYADMINSREQUEST = _descriptor.Descriptor(
  name='ModifyAdminsRequest',
  full_name='auth_1_10.ModifyAdminsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='add', full_name='auth_1_10.ModifyAdminsRequest.add', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='auth_1_10.ModifyAdminsRequest.remove', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1020,
  serialized_end=1070,
)


_MODIFYADMINSRESPONSE = _descriptor.Descriptor(
  name='ModifyAdminsResponse',
  full_name='auth_1_10.ModifyAdminsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1072,
  serialized_end=1094,
)


_OTPINFO = _descriptor.Descriptor(
  name='OTPInfo',
  full_name='auth_1_10.OTPInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='auth_1_10.OTPInfo.subject', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_expiration', full_name='auth_1_10.OTPInfo.session_expiration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1096,
  serialized_end=1178,
)


_TOKENINFO = _descriptor.Descriptor(
  name='TokenInfo',
  full_name='auth_1_10.TokenInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='auth_1_10.TokenInfo.subject', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='auth_1_10.TokenInfo.source', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TOKENINFO_TOKENSOURCE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1181,
  serialized_end=1320,
)


_AUTHENTICATEREQUEST = _descriptor.Descriptor(
  name='AuthenticateRequest',
  full_name='auth_1_10.AuthenticateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='github_token', full_name='auth_1_10.AuthenticateRequest.github_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='one_time_password', full_name='auth_1_10.AuthenticateRequest.one_time_password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1322,
  serialized_end=1392,
)


_AUTHENTICATERESPONSE = _descriptor.Descriptor(
  name='AuthenticateResponse',
  full_name='auth_1_10.AuthenticateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pach_token', full_name='auth_1_10.AuthenticateResponse.pach_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1394,
  serialized_end=1436,
)


_WHOAMIREQUEST = _descriptor.Descriptor(
  name='WhoAmIRequest',
  full_name='auth_1_10.WhoAmIRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1438,
  serialized_end=1453,
)


_WHOAMIRESPONSE = _descriptor.Descriptor(
  name='WhoAmIResponse',
  full_name='auth_1_10.WhoAmIResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='auth_1_10.WhoAmIResponse.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_admin', full_name='auth_1_10.WhoAmIResponse.is_admin', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='auth_1_10.WhoAmIResponse.ttl', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1455,
  serialized_end=1520,
)


_ACL_ENTRIESENTRY = _descriptor.Descriptor(
  name='EntriesEntry',
  full_name='auth_1_10.ACL.EntriesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='auth_1_10.ACL.EntriesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='auth_1_10.ACL.EntriesEntry.value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1575,
  serialized_end=1639,
)

_ACL = _descriptor.Descriptor(
  name='ACL',
  full_name='auth_1_10.ACL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='auth_1_10.ACL.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ACL_ENTRIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1522,
  serialized_end=1639,
)


_USERS_USERNAMESENTRY = _descriptor.Descriptor(
  name='UsernamesEntry',
  full_name='auth_1_10.Users.UsernamesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='auth_1_10.Users.UsernamesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='auth_1_10.Users.UsernamesEntry.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1702,
  serialized_end=1750,
)

_USERS = _descriptor.Descriptor(
  name='Users',
  full_name='auth_1_10.Users',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='usernames', full_name='auth_1_10.Users.usernames', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_USERS_USERNAMESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1641,
  serialized_end=1750,
)


_GROUPS_GROUPSENTRY = _descriptor.Descriptor(
  name='GroupsEntry',
  full_name='auth_1_10.Groups.GroupsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='auth_1_10.Groups.GroupsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='auth_1_10.Groups.GroupsEntry.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1809,
  serialized_end=1854,
)

_GROUPS = _descriptor.Descriptor(
  name='Groups',
  full_name='auth_1_10.Groups',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='auth_1_10.Groups.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GROUPS_GROUPSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1752,
  serialized_end=1854,
)


_AUTHORIZEREQUEST = _descriptor.Descriptor(
  name='AuthorizeRequest',
  full_name='auth_1_10.AuthorizeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='auth_1_10.AuthorizeRequest.repo', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scope', full_name='auth_1_10.AuthorizeRequest.scope', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1856,
  serialized_end=1921,
)


_AUTHORIZERESPONSE = _descriptor.Descriptor(
  name='AuthorizeResponse',
  full_name='auth_1_10.AuthorizeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='authorized', full_name='auth_1_10.AuthorizeResponse.authorized', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1923,
  serialized_end=1962,
)


_GETSCOPEREQUEST = _descriptor.Descriptor(
  name='GetScopeRequest',
  full_name='auth_1_10.GetScopeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='auth_1_10.GetScopeRequest.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repos', full_name='auth_1_10.GetScopeRequest.repos', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1964,
  serialized_end=2014,
)


_GETSCOPERESPONSE = _descriptor.Descriptor(
  name='GetScopeResponse',
  full_name='auth_1_10.GetScopeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scopes', full_name='auth_1_10.GetScopeResponse.scopes', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2016,
  serialized_end=2068,
)


_SETSCOPEREQUEST = _descriptor.Descriptor(
  name='SetScopeRequest',
  full_name='auth_1_10.SetScopeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='auth_1_10.SetScopeRequest.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='repo', full_name='auth_1_10.SetScopeRequest.repo', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scope', full_name='auth_1_10.SetScopeRequest.scope', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2070,
  serialized_end=2152,
)


_SETSCOPERESPONSE = _descriptor.Descriptor(
  name='SetScopeResponse',
  full_name='auth_1_10.SetScopeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2154,
  serialized_end=2172,
)


_GETACLREQUEST = _descriptor.Descriptor(
  name='GetACLRequest',
  full_name='auth_1_10.GetACLRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='auth_1_10.GetACLRequest.repo', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2174,
  serialized_end=2203,
)


_ACLENTRY = _descriptor.Descriptor(
  name='ACLEntry',
  full_name='auth_1_10.ACLEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='auth_1_10.ACLEntry.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scope', full_name='auth_1_10.ACLEntry.scope', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2205,
  serialized_end=2266,
)


_GETACLRESPONSE = _descriptor.Descriptor(
  name='GetACLResponse',
  full_name='auth_1_10.GetACLResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='auth_1_10.GetACLResponse.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='robot_entries', full_name='auth_1_10.GetACLResponse.robot_entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2268,
  serialized_end=2366,
)


_SETACLREQUEST = _descriptor.Descriptor(
  name='SetACLRequest',
  full_name='auth_1_10.SetACLRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='auth_1_10.SetACLRequest.repo', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='auth_1_10.SetACLRequest.entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2368,
  serialized_end=2435,
)


_SETACLRESPONSE = _descriptor.Descriptor(
  name='SetACLResponse',
  full_name='auth_1_10.SetACLResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2437,
  serialized_end=2453,
)


_GETAUTHTOKENREQUEST = _descriptor.Descriptor(
  name='GetAuthTokenRequest',
  full_name='auth_1_10.GetAuthTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='auth_1_10.GetAuthTokenRequest.subject', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='auth_1_10.GetAuthTokenRequest.ttl', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2455,
  serialized_end=2506,
)


_GETAUTHTOKENRESPONSE = _descriptor.Descriptor(
  name='GetAuthTokenResponse',
  full_name='auth_1_10.GetAuthTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='auth_1_10.GetAuthTokenResponse.subject', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='auth_1_10.GetAuthTokenResponse.token', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2508,
  serialized_end=2562,
)


_EXTENDAUTHTOKENREQUEST = _descriptor.Descriptor(
  name='ExtendAuthTokenRequest',
  full_name='auth_1_10.ExtendAuthTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='auth_1_10.ExtendAuthTokenRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='auth_1_10.ExtendAuthTokenRequest.ttl', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2564,
  serialized_end=2616,
)


_EXTENDAUTHTOKENRESPONSE = _descriptor.Descriptor(
  name='ExtendAuthTokenResponse',
  full_name='auth_1_10.ExtendAuthTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2618,
  serialized_end=2643,
)


_REVOKEAUTHTOKENREQUEST = _descriptor.Descriptor(
  name='RevokeAuthTokenRequest',
  full_name='auth_1_10.RevokeAuthTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='auth_1_10.RevokeAuthTokenRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2645,
  serialized_end=2684,
)


_REVOKEAUTHTOKENRESPONSE = _descriptor.Descriptor(
  name='RevokeAuthTokenResponse',
  full_name='auth_1_10.RevokeAuthTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2686,
  serialized_end=2711,
)


_SETGROUPSFORUSERREQUEST = _descriptor.Descriptor(
  name='SetGroupsForUserRequest',
  full_name='auth_1_10.SetGroupsForUserRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='auth_1_10.SetGroupsForUserRequest.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groups', full_name='auth_1_10.SetGroupsForUserRequest.groups', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2713,
  serialized_end=2772,
)


_SETGROUPSFORUSERRESPONSE = _descriptor.Descriptor(
  name='SetGroupsForUserResponse',
  full_name='auth_1_10.SetGroupsForUserResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2774,
  serialized_end=2800,
)


_MODIFYMEMBERSREQUEST = _descriptor.Descriptor(
  name='ModifyMembersRequest',
  full_name='auth_1_10.ModifyMembersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='auth_1_10.ModifyMembersRequest.group', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='add', full_name='auth_1_10.ModifyMembersRequest.add', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='auth_1_10.ModifyMembersRequest.remove', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2802,
  serialized_end=2868,
)


_MODIFYMEMBERSRESPONSE = _descriptor.Descriptor(
  name='ModifyMembersResponse',
  full_name='auth_1_10.ModifyMembersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2870,
  serialized_end=2893,
)


_GETGROUPSREQUEST = _descriptor.Descriptor(
  name='GetGroupsRequest',
  full_name='auth_1_10.GetGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='auth_1_10.GetGroupsRequest.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2895,
  serialized_end=2931,
)


_GETGROUPSRESPONSE = _descriptor.Descriptor(
  name='GetGroupsResponse',
  full_name='auth_1_10.GetGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='auth_1_10.GetGroupsResponse.groups', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2933,
  serialized_end=2968,
)


_GETUSERSREQUEST = _descriptor.Descriptor(
  name='GetUsersRequest',
  full_name='auth_1_10.GetUsersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='auth_1_10.GetUsersRequest.group', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2970,
  serialized_end=3002,
)


_GETUSERSRESPONSE = _descriptor.Descriptor(
  name='GetUsersResponse',
  full_name='auth_1_10.GetUsersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='usernames', full_name='auth_1_10.GetUsersResponse.usernames', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3004,
  serialized_end=3041,
)


_GETONETIMEPASSWORDREQUEST = _descriptor.Descriptor(
  name='GetOneTimePasswordRequest',
  full_name='auth_1_10.GetOneTimePasswordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subject', full_name='auth_1_10.GetOneTimePasswordRequest.subject', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='auth_1_10.GetOneTimePasswordRequest.ttl', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3043,
  serialized_end=3100,
)


_GETONETIMEPASSWORDRESPONSE = _descriptor.Descriptor(
  name='GetOneTimePasswordResponse',
  full_name='auth_1_10.GetOneTimePasswordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='auth_1_10.GetOneTimePasswordResponse.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='otp_expiration', full_name='auth_1_10.GetOneTimePasswordResponse.otp_expiration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3102,
  serialized_end=3196,
)

_IDPROVIDER_SAMLOPTIONS.containing_type = _IDPROVIDER
_IDPROVIDER_GITHUBOPTIONS.containing_type = _IDPROVIDER
_IDPROVIDER.fields_by_name['saml'].message_type = _IDPROVIDER_SAMLOPTIONS
_IDPROVIDER.fields_by_name['github'].message_type = _IDPROVIDER_GITHUBOPTIONS
_AUTHCONFIG_SAMLSERVICEOPTIONS.containing_type = _AUTHCONFIG
_AUTHCONFIG.fields_by_name['id_providers'].message_type = _IDPROVIDER
_AUTHCONFIG.fields_by_name['saml_svc_options'].message_type = _AUTHCONFIG_SAMLSERVICEOPTIONS
_GETCONFIGURATIONRESPONSE.fields_by_name['configuration'].message_type = _AUTHCONFIG
_SETCONFIGURATIONREQUEST.fields_by_name['configuration'].message_type = _AUTHCONFIG
_OTPINFO.fields_by_name['session_expiration'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TOKENINFO.fields_by_name['source'].enum_type = _TOKENINFO_TOKENSOURCE
_TOKENINFO_TOKENSOURCE.containing_type = _TOKENINFO
_ACL_ENTRIESENTRY.fields_by_name['value'].enum_type = _SCOPE
_ACL_ENTRIESENTRY.containing_type = _ACL
_ACL.fields_by_name['entries'].message_type = _ACL_ENTRIESENTRY
_USERS_USERNAMESENTRY.containing_type = _USERS
_USERS.fields_by_name['usernames'].message_type = _USERS_USERNAMESENTRY
_GROUPS_GROUPSENTRY.containing_type = _GROUPS
_GROUPS.fields_by_name['groups'].message_type = _GROUPS_GROUPSENTRY
_AUTHORIZEREQUEST.fields_by_name['scope'].enum_type = _SCOPE
_GETSCOPERESPONSE.fields_by_name['scopes'].enum_type = _SCOPE
_SETSCOPEREQUEST.fields_by_name['scope'].enum_type = _SCOPE
_ACLENTRY.fields_by_name['scope'].enum_type = _SCOPE
_GETACLRESPONSE.fields_by_name['entries'].message_type = _ACLENTRY
_GETACLRESPONSE.fields_by_name['robot_entries'].message_type = _ACLENTRY
_SETACLREQUEST.fields_by_name['entries'].message_type = _ACLENTRY
_GETONETIMEPASSWORDRESPONSE.fields_by_name['otp_expiration'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['ActivateRequest'] = _ACTIVATEREQUEST
DESCRIPTOR.message_types_by_name['ActivateResponse'] = _ACTIVATERESPONSE
DESCRIPTOR.message_types_by_name['DeactivateRequest'] = _DEACTIVATEREQUEST
DESCRIPTOR.message_types_by_name['DeactivateResponse'] = _DEACTIVATERESPONSE
DESCRIPTOR.message_types_by_name['IDProvider'] = _IDPROVIDER
DESCRIPTOR.message_types_by_name['AuthConfig'] = _AUTHCONFIG
DESCRIPTOR.message_types_by_name['GetConfigurationRequest'] = _GETCONFIGURATIONREQUEST
DESCRIPTOR.message_types_by_name['GetConfigurationResponse'] = _GETCONFIGURATIONRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigurationRequest'] = _SETCONFIGURATIONREQUEST
DESCRIPTOR.message_types_by_name['SetConfigurationResponse'] = _SETCONFIGURATIONRESPONSE
DESCRIPTOR.message_types_by_name['GetAdminsRequest'] = _GETADMINSREQUEST
DESCRIPTOR.message_types_by_name['GetAdminsResponse'] = _GETADMINSRESPONSE
DESCRIPTOR.message_types_by_name['ModifyAdminsRequest'] = _MODIFYADMINSREQUEST
DESCRIPTOR.message_types_by_name['ModifyAdminsResponse'] = _MODIFYADMINSRESPONSE
DESCRIPTOR.message_types_by_name['OTPInfo'] = _OTPINFO
DESCRIPTOR.message_types_by_name['TokenInfo'] = _TOKENINFO
DESCRIPTOR.message_types_by_name['AuthenticateRequest'] = _AUTHENTICATEREQUEST
DESCRIPTOR.message_types_by_name['AuthenticateResponse'] = _AUTHENTICATERESPONSE
DESCRIPTOR.message_types_by_name['WhoAmIRequest'] = _WHOAMIREQUEST
DESCRIPTOR.message_types_by_name['WhoAmIResponse'] = _WHOAMIRESPONSE
DESCRIPTOR.message_types_by_name['ACL'] = _ACL
DESCRIPTOR.message_types_by_name['Users'] = _USERS
DESCRIPTOR.message_types_by_name['Groups'] = _GROUPS
DESCRIPTOR.message_types_by_name['AuthorizeRequest'] = _AUTHORIZEREQUEST
DESCRIPTOR.message_types_by_name['AuthorizeResponse'] = _AUTHORIZERESPONSE
DESCRIPTOR.message_types_by_name['GetScopeRequest'] = _GETSCOPEREQUEST
DESCRIPTOR.message_types_by_name['GetScopeResponse'] = _GETSCOPERESPONSE
DESCRIPTOR.message_types_by_name['SetScopeRequest'] = _SETSCOPEREQUEST
DESCRIPTOR.message_types_by_name['SetScopeResponse'] = _SETSCOPERESPONSE
DESCRIPTOR.message_types_by_name['GetACLRequest'] = _GETACLREQUEST
DESCRIPTOR.message_types_by_name['ACLEntry'] = _ACLENTRY
DESCRIPTOR.message_types_by_name['GetACLResponse'] = _GETACLRESPONSE
DESCRIPTOR.message_types_by_name['SetACLRequest'] = _SETACLREQUEST
DESCRIPTOR.message_types_by_name['SetACLResponse'] = _SETACLRESPONSE
DESCRIPTOR.message_types_by_name['GetAuthTokenRequest'] = _GETAUTHTOKENREQUEST
DESCRIPTOR.message_types_by_name['GetAuthTokenResponse'] = _GETAUTHTOKENRESPONSE
DESCRIPTOR.message_types_by_name['ExtendAuthTokenRequest'] = _EXTENDAUTHTOKENREQUEST
DESCRIPTOR.message_types_by_name['ExtendAuthTokenResponse'] = _EXTENDAUTHTOKENRESPONSE
DESCRIPTOR.message_types_by_name['RevokeAuthTokenRequest'] = _REVOKEAUTHTOKENREQUEST
DESCRIPTOR.message_types_by_name['RevokeAuthTokenResponse'] = _REVOKEAUTHTOKENRESPONSE
DESCRIPTOR.message_types_by_name['SetGroupsForUserRequest'] = _SETGROUPSFORUSERREQUEST
DESCRIPTOR.message_types_by_name['SetGroupsForUserResponse'] = _SETGROUPSFORUSERRESPONSE
DESCRIPTOR.message_types_by_name['ModifyMembersRequest'] = _MODIFYMEMBERSREQUEST
DESCRIPTOR.message_types_by_name['ModifyMembersResponse'] = _MODIFYMEMBERSRESPONSE
DESCRIPTOR.message_types_by_name['GetGroupsRequest'] = _GETGROUPSREQUEST
DESCRIPTOR.message_types_by_name['GetGroupsResponse'] = _GETGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['GetUsersRequest'] = _GETUSERSREQUEST
DESCRIPTOR.message_types_by_name['GetUsersResponse'] = _GETUSERSRESPONSE
DESCRIPTOR.message_types_by_name['GetOneTimePasswordRequest'] = _GETONETIMEPASSWORDREQUEST
DESCRIPTOR.message_types_by_name['GetOneTimePasswordResponse'] = _GETONETIMEPASSWORDRESPONSE
DESCRIPTOR.enum_types_by_name['Scope'] = _SCOPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ActivateRequest = _reflection.GeneratedProtocolMessageType('ActivateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.ActivateRequest)
  })
_sym_db.RegisterMessage(ActivateRequest)

ActivateResponse = _reflection.GeneratedProtocolMessageType('ActivateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATERESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.ActivateResponse)
  })
_sym_db.RegisterMessage(ActivateResponse)

DeactivateRequest = _reflection.GeneratedProtocolMessageType('DeactivateRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEACTIVATEREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.DeactivateRequest)
  })
_sym_db.RegisterMessage(DeactivateRequest)

DeactivateResponse = _reflection.GeneratedProtocolMessageType('DeactivateResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEACTIVATERESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.DeactivateResponse)
  })
_sym_db.RegisterMessage(DeactivateResponse)

IDProvider = _reflection.GeneratedProtocolMessageType('IDProvider', (_message.Message,), {

  'SAMLOptions' : _reflection.GeneratedProtocolMessageType('SAMLOptions', (_message.Message,), {
    'DESCRIPTOR' : _IDPROVIDER_SAMLOPTIONS,
    '__module__' : 'client.admin.v1_10.auth.auth_pb2'
    # @@protoc_insertion_point(class_scope:auth_1_10.IDProvider.SAMLOptions)
    })
  ,

  'GitHubOptions' : _reflection.GeneratedProtocolMessageType('GitHubOptions', (_message.Message,), {
    'DESCRIPTOR' : _IDPROVIDER_GITHUBOPTIONS,
    '__module__' : 'client.admin.v1_10.auth.auth_pb2'
    # @@protoc_insertion_point(class_scope:auth_1_10.IDProvider.GitHubOptions)
    })
  ,
  'DESCRIPTOR' : _IDPROVIDER,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.IDProvider)
  })
_sym_db.RegisterMessage(IDProvider)
_sym_db.RegisterMessage(IDProvider.SAMLOptions)
_sym_db.RegisterMessage(IDProvider.GitHubOptions)

AuthConfig = _reflection.GeneratedProtocolMessageType('AuthConfig', (_message.Message,), {

  'SAMLServiceOptions' : _reflection.GeneratedProtocolMessageType('SAMLServiceOptions', (_message.Message,), {
    'DESCRIPTOR' : _AUTHCONFIG_SAMLSERVICEOPTIONS,
    '__module__' : 'client.admin.v1_10.auth.auth_pb2'
    # @@protoc_insertion_point(class_scope:auth_1_10.AuthConfig.SAMLServiceOptions)
    })
  ,
  'DESCRIPTOR' : _AUTHCONFIG,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.AuthConfig)
  })
_sym_db.RegisterMessage(AuthConfig)
_sym_db.RegisterMessage(AuthConfig.SAMLServiceOptions)

GetConfigurationRequest = _reflection.GeneratedProtocolMessageType('GetConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGURATIONREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.GetConfigurationRequest)
  })
_sym_db.RegisterMessage(GetConfigurationRequest)

GetConfigurationResponse = _reflection.GeneratedProtocolMessageType('GetConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGURATIONRESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.GetConfigurationResponse)
  })
_sym_db.RegisterMessage(GetConfigurationResponse)

SetConfigurationRequest = _reflection.GeneratedProtocolMessageType('SetConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGURATIONREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.SetConfigurationRequest)
  })
_sym_db.RegisterMessage(SetConfigurationRequest)

SetConfigurationResponse = _reflection.GeneratedProtocolMessageType('SetConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGURATIONRESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.SetConfigurationResponse)
  })
_sym_db.RegisterMessage(SetConfigurationResponse)

GetAdminsRequest = _reflection.GeneratedProtocolMessageType('GetAdminsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETADMINSREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.GetAdminsRequest)
  })
_sym_db.RegisterMessage(GetAdminsRequest)

GetAdminsResponse = _reflection.GeneratedProtocolMessageType('GetAdminsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETADMINSRESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.GetAdminsResponse)
  })
_sym_db.RegisterMessage(GetAdminsResponse)

ModifyAdminsRequest = _reflection.GeneratedProtocolMessageType('ModifyAdminsRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYADMINSREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.ModifyAdminsRequest)
  })
_sym_db.RegisterMessage(ModifyAdminsRequest)

ModifyAdminsResponse = _reflection.GeneratedProtocolMessageType('ModifyAdminsResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYADMINSRESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.ModifyAdminsResponse)
  })
_sym_db.RegisterMessage(ModifyAdminsResponse)

OTPInfo = _reflection.GeneratedProtocolMessageType('OTPInfo', (_message.Message,), {
  'DESCRIPTOR' : _OTPINFO,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.OTPInfo)
  })
_sym_db.RegisterMessage(OTPInfo)

TokenInfo = _reflection.GeneratedProtocolMessageType('TokenInfo', (_message.Message,), {
  'DESCRIPTOR' : _TOKENINFO,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.TokenInfo)
  })
_sym_db.RegisterMessage(TokenInfo)

AuthenticateRequest = _reflection.GeneratedProtocolMessageType('AuthenticateRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATEREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.AuthenticateRequest)
  })
_sym_db.RegisterMessage(AuthenticateRequest)

AuthenticateResponse = _reflection.GeneratedProtocolMessageType('AuthenticateResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATERESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.AuthenticateResponse)
  })
_sym_db.RegisterMessage(AuthenticateResponse)

WhoAmIRequest = _reflection.GeneratedProtocolMessageType('WhoAmIRequest', (_message.Message,), {
  'DESCRIPTOR' : _WHOAMIREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.WhoAmIRequest)
  })
_sym_db.RegisterMessage(WhoAmIRequest)

WhoAmIResponse = _reflection.GeneratedProtocolMessageType('WhoAmIResponse', (_message.Message,), {
  'DESCRIPTOR' : _WHOAMIRESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.WhoAmIResponse)
  })
_sym_db.RegisterMessage(WhoAmIResponse)

ACL = _reflection.GeneratedProtocolMessageType('ACL', (_message.Message,), {

  'EntriesEntry' : _reflection.GeneratedProtocolMessageType('EntriesEntry', (_message.Message,), {
    'DESCRIPTOR' : _ACL_ENTRIESENTRY,
    '__module__' : 'client.admin.v1_10.auth.auth_pb2'
    # @@protoc_insertion_point(class_scope:auth_1_10.ACL.EntriesEntry)
    })
  ,
  'DESCRIPTOR' : _ACL,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.ACL)
  })
_sym_db.RegisterMessage(ACL)
_sym_db.RegisterMessage(ACL.EntriesEntry)

Users = _reflection.GeneratedProtocolMessageType('Users', (_message.Message,), {

  'UsernamesEntry' : _reflection.GeneratedProtocolMessageType('UsernamesEntry', (_message.Message,), {
    'DESCRIPTOR' : _USERS_USERNAMESENTRY,
    '__module__' : 'client.admin.v1_10.auth.auth_pb2'
    # @@protoc_insertion_point(class_scope:auth_1_10.Users.UsernamesEntry)
    })
  ,
  'DESCRIPTOR' : _USERS,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.Users)
  })
_sym_db.RegisterMessage(Users)
_sym_db.RegisterMessage(Users.UsernamesEntry)

Groups = _reflection.GeneratedProtocolMessageType('Groups', (_message.Message,), {

  'GroupsEntry' : _reflection.GeneratedProtocolMessageType('GroupsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GROUPS_GROUPSENTRY,
    '__module__' : 'client.admin.v1_10.auth.auth_pb2'
    # @@protoc_insertion_point(class_scope:auth_1_10.Groups.GroupsEntry)
    })
  ,
  'DESCRIPTOR' : _GROUPS,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.Groups)
  })
_sym_db.RegisterMessage(Groups)
_sym_db.RegisterMessage(Groups.GroupsEntry)

AuthorizeRequest = _reflection.GeneratedProtocolMessageType('AuthorizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZEREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.AuthorizeRequest)
  })
_sym_db.RegisterMessage(AuthorizeRequest)

AuthorizeResponse = _reflection.GeneratedProtocolMessageType('AuthorizeResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZERESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.AuthorizeResponse)
  })
_sym_db.RegisterMessage(AuthorizeResponse)

GetScopeRequest = _reflection.GeneratedProtocolMessageType('GetScopeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSCOPEREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.GetScopeRequest)
  })
_sym_db.RegisterMessage(GetScopeRequest)

GetScopeResponse = _reflection.GeneratedProtocolMessageType('GetScopeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSCOPERESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.GetScopeResponse)
  })
_sym_db.RegisterMessage(GetScopeResponse)

SetScopeRequest = _reflection.GeneratedProtocolMessageType('SetScopeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETSCOPEREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.SetScopeRequest)
  })
_sym_db.RegisterMessage(SetScopeRequest)

SetScopeResponse = _reflection.GeneratedProtocolMessageType('SetScopeResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETSCOPERESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.SetScopeResponse)
  })
_sym_db.RegisterMessage(SetScopeResponse)

GetACLRequest = _reflection.GeneratedProtocolMessageType('GetACLRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACLREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.GetACLRequest)
  })
_sym_db.RegisterMessage(GetACLRequest)

ACLEntry = _reflection.GeneratedProtocolMessageType('ACLEntry', (_message.Message,), {
  'DESCRIPTOR' : _ACLENTRY,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.ACLEntry)
  })
_sym_db.RegisterMessage(ACLEntry)

GetACLResponse = _reflection.GeneratedProtocolMessageType('GetACLResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACLRESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.GetACLResponse)
  })
_sym_db.RegisterMessage(GetACLResponse)

SetACLRequest = _reflection.GeneratedProtocolMessageType('SetACLRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETACLREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.SetACLRequest)
  })
_sym_db.RegisterMessage(SetACLRequest)

SetACLResponse = _reflection.GeneratedProtocolMessageType('SetACLResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETACLRESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.SetACLResponse)
  })
_sym_db.RegisterMessage(SetACLResponse)

GetAuthTokenRequest = _reflection.GeneratedProtocolMessageType('GetAuthTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTHTOKENREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.GetAuthTokenRequest)
  })
_sym_db.RegisterMessage(GetAuthTokenRequest)

GetAuthTokenResponse = _reflection.GeneratedProtocolMessageType('GetAuthTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAUTHTOKENRESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.GetAuthTokenResponse)
  })
_sym_db.RegisterMessage(GetAuthTokenResponse)

ExtendAuthTokenRequest = _reflection.GeneratedProtocolMessageType('ExtendAuthTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXTENDAUTHTOKENREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.ExtendAuthTokenRequest)
  })
_sym_db.RegisterMessage(ExtendAuthTokenRequest)

ExtendAuthTokenResponse = _reflection.GeneratedProtocolMessageType('ExtendAuthTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXTENDAUTHTOKENRESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.ExtendAuthTokenResponse)
  })
_sym_db.RegisterMessage(ExtendAuthTokenResponse)

RevokeAuthTokenRequest = _reflection.GeneratedProtocolMessageType('RevokeAuthTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEAUTHTOKENREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.RevokeAuthTokenRequest)
  })
_sym_db.RegisterMessage(RevokeAuthTokenRequest)

RevokeAuthTokenResponse = _reflection.GeneratedProtocolMessageType('RevokeAuthTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEAUTHTOKENRESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.RevokeAuthTokenResponse)
  })
_sym_db.RegisterMessage(RevokeAuthTokenResponse)

SetGroupsForUserRequest = _reflection.GeneratedProtocolMessageType('SetGroupsForUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETGROUPSFORUSERREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.SetGroupsForUserRequest)
  })
_sym_db.RegisterMessage(SetGroupsForUserRequest)

SetGroupsForUserResponse = _reflection.GeneratedProtocolMessageType('SetGroupsForUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETGROUPSFORUSERRESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.SetGroupsForUserResponse)
  })
_sym_db.RegisterMessage(SetGroupsForUserResponse)

ModifyMembersRequest = _reflection.GeneratedProtocolMessageType('ModifyMembersRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYMEMBERSREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.ModifyMembersRequest)
  })
_sym_db.RegisterMessage(ModifyMembersRequest)

ModifyMembersResponse = _reflection.GeneratedProtocolMessageType('ModifyMembersResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYMEMBERSRESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.ModifyMembersResponse)
  })
_sym_db.RegisterMessage(ModifyMembersResponse)

GetGroupsRequest = _reflection.GeneratedProtocolMessageType('GetGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETGROUPSREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.GetGroupsRequest)
  })
_sym_db.RegisterMessage(GetGroupsRequest)

GetGroupsResponse = _reflection.GeneratedProtocolMessageType('GetGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETGROUPSRESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.GetGroupsResponse)
  })
_sym_db.RegisterMessage(GetGroupsResponse)

GetUsersRequest = _reflection.GeneratedProtocolMessageType('GetUsersRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERSREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.GetUsersRequest)
  })
_sym_db.RegisterMessage(GetUsersRequest)

GetUsersResponse = _reflection.GeneratedProtocolMessageType('GetUsersResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERSRESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.GetUsersResponse)
  })
_sym_db.RegisterMessage(GetUsersResponse)

GetOneTimePasswordRequest = _reflection.GeneratedProtocolMessageType('GetOneTimePasswordRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETONETIMEPASSWORDREQUEST,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.GetOneTimePasswordRequest)
  })
_sym_db.RegisterMessage(GetOneTimePasswordRequest)

GetOneTimePasswordResponse = _reflection.GeneratedProtocolMessageType('GetOneTimePasswordResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETONETIMEPASSWORDRESPONSE,
  '__module__' : 'client.admin.v1_10.auth.auth_pb2'
  # @@protoc_insertion_point(class_scope:auth_1_10.GetOneTimePasswordResponse)
  })
_sym_db.RegisterMessage(GetOneTimePasswordResponse)


DESCRIPTOR._options = None
_ACL_ENTRIESENTRY._options = None
_USERS_USERNAMESENTRY._options = None
_GROUPS_GROUPSENTRY._options = None

_API = _descriptor.ServiceDescriptor(
  name='API',
  full_name='auth_1_10.API',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=3253,
  serialized_end=4941,
  methods=[
  _descriptor.MethodDescriptor(
    name='Activate',
    full_name='auth_1_10.API.Activate',
    index=0,
    containing_service=None,
    input_type=_ACTIVATEREQUEST,
    output_type=_ACTIVATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Deactivate',
    full_name='auth_1_10.API.Deactivate',
    index=1,
    containing_service=None,
    input_type=_DEACTIVATEREQUEST,
    output_type=_DEACTIVATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetConfiguration',
    full_name='auth_1_10.API.GetConfiguration',
    index=2,
    containing_service=None,
    input_type=_GETCONFIGURATIONREQUEST,
    output_type=_GETCONFIGURATIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfiguration',
    full_name='auth_1_10.API.SetConfiguration',
    index=3,
    containing_service=None,
    input_type=_SETCONFIGURATIONREQUEST,
    output_type=_SETCONFIGURATIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAdmins',
    full_name='auth_1_10.API.GetAdmins',
    index=4,
    containing_service=None,
    input_type=_GETADMINSREQUEST,
    output_type=_GETADMINSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ModifyAdmins',
    full_name='auth_1_10.API.ModifyAdmins',
    index=5,
    containing_service=None,
    input_type=_MODIFYADMINSREQUEST,
    output_type=_MODIFYADMINSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Authenticate',
    full_name='auth_1_10.API.Authenticate',
    index=6,
    containing_service=None,
    input_type=_AUTHENTICATEREQUEST,
    output_type=_AUTHENTICATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Authorize',
    full_name='auth_1_10.API.Authorize',
    index=7,
    containing_service=None,
    input_type=_AUTHORIZEREQUEST,
    output_type=_AUTHORIZERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='WhoAmI',
    full_name='auth_1_10.API.WhoAmI',
    index=8,
    containing_service=None,
    input_type=_WHOAMIREQUEST,
    output_type=_WHOAMIRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetScope',
    full_name='auth_1_10.API.GetScope',
    index=9,
    containing_service=None,
    input_type=_GETSCOPEREQUEST,
    output_type=_GETSCOPERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetScope',
    full_name='auth_1_10.API.SetScope',
    index=10,
    containing_service=None,
    input_type=_SETSCOPEREQUEST,
    output_type=_SETSCOPERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetACL',
    full_name='auth_1_10.API.GetACL',
    index=11,
    containing_service=None,
    input_type=_GETACLREQUEST,
    output_type=_GETACLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetACL',
    full_name='auth_1_10.API.SetACL',
    index=12,
    containing_service=None,
    input_type=_SETACLREQUEST,
    output_type=_SETACLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAuthToken',
    full_name='auth_1_10.API.GetAuthToken',
    index=13,
    containing_service=None,
    input_type=_GETAUTHTOKENREQUEST,
    output_type=_GETAUTHTOKENRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ExtendAuthToken',
    full_name='auth_1_10.API.ExtendAuthToken',
    index=14,
    containing_service=None,
    input_type=_EXTENDAUTHTOKENREQUEST,
    output_type=_EXTENDAUTHTOKENRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='RevokeAuthToken',
    full_name='auth_1_10.API.RevokeAuthToken',
    index=15,
    containing_service=None,
    input_type=_REVOKEAUTHTOKENREQUEST,
    output_type=_REVOKEAUTHTOKENRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetGroupsForUser',
    full_name='auth_1_10.API.SetGroupsForUser',
    index=16,
    containing_service=None,
    input_type=_SETGROUPSFORUSERREQUEST,
    output_type=_SETGROUPSFORUSERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ModifyMembers',
    full_name='auth_1_10.API.ModifyMembers',
    index=17,
    containing_service=None,
    input_type=_MODIFYMEMBERSREQUEST,
    output_type=_MODIFYMEMBERSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetGroups',
    full_name='auth_1_10.API.GetGroups',
    index=18,
    containing_service=None,
    input_type=_GETGROUPSREQUEST,
    output_type=_GETGROUPSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetUsers',
    full_name='auth_1_10.API.GetUsers',
    index=19,
    containing_service=None,
    input_type=_GETUSERSREQUEST,
    output_type=_GETUSERSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetOneTimePassword',
    full_name='auth_1_10.API.GetOneTimePassword',
    index=20,
    containing_service=None,
    input_type=_GETONETIMEPASSWORDREQUEST,
    output_type=_GETONETIMEPASSWORDRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_API)

DESCRIPTOR.services_by_name['API'] = _API

# @@protoc_insertion_point(module_scope)
