# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from python_pachyderm.proto.admin.v1_10.auth import auth_pb2 as client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2


class APIStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Activate = channel.unary_unary(
        '/auth_1_10.API/Activate',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.ActivateRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.ActivateResponse.FromString,
        )
    self.Deactivate = channel.unary_unary(
        '/auth_1_10.API/Deactivate',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.DeactivateRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.DeactivateResponse.FromString,
        )
    self.GetConfiguration = channel.unary_unary(
        '/auth_1_10.API/GetConfiguration',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetConfigurationRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetConfigurationResponse.FromString,
        )
    self.SetConfiguration = channel.unary_unary(
        '/auth_1_10.API/SetConfiguration',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.SetConfigurationRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.SetConfigurationResponse.FromString,
        )
    self.GetAdmins = channel.unary_unary(
        '/auth_1_10.API/GetAdmins',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetAdminsRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetAdminsResponse.FromString,
        )
    self.ModifyAdmins = channel.unary_unary(
        '/auth_1_10.API/ModifyAdmins',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.ModifyAdminsRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.ModifyAdminsResponse.FromString,
        )
    self.Authenticate = channel.unary_unary(
        '/auth_1_10.API/Authenticate',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.AuthenticateRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.AuthenticateResponse.FromString,
        )
    self.Authorize = channel.unary_unary(
        '/auth_1_10.API/Authorize',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.AuthorizeRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.AuthorizeResponse.FromString,
        )
    self.WhoAmI = channel.unary_unary(
        '/auth_1_10.API/WhoAmI',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.WhoAmIRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.WhoAmIResponse.FromString,
        )
    self.GetScope = channel.unary_unary(
        '/auth_1_10.API/GetScope',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetScopeRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetScopeResponse.FromString,
        )
    self.SetScope = channel.unary_unary(
        '/auth_1_10.API/SetScope',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.SetScopeRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.SetScopeResponse.FromString,
        )
    self.GetACL = channel.unary_unary(
        '/auth_1_10.API/GetACL',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetACLRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetACLResponse.FromString,
        )
    self.SetACL = channel.unary_unary(
        '/auth_1_10.API/SetACL',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.SetACLRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.SetACLResponse.FromString,
        )
    self.GetAuthToken = channel.unary_unary(
        '/auth_1_10.API/GetAuthToken',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetAuthTokenRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetAuthTokenResponse.FromString,
        )
    self.ExtendAuthToken = channel.unary_unary(
        '/auth_1_10.API/ExtendAuthToken',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.ExtendAuthTokenRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.ExtendAuthTokenResponse.FromString,
        )
    self.RevokeAuthToken = channel.unary_unary(
        '/auth_1_10.API/RevokeAuthToken',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.RevokeAuthTokenRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.RevokeAuthTokenResponse.FromString,
        )
    self.SetGroupsForUser = channel.unary_unary(
        '/auth_1_10.API/SetGroupsForUser',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.SetGroupsForUserRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.SetGroupsForUserResponse.FromString,
        )
    self.ModifyMembers = channel.unary_unary(
        '/auth_1_10.API/ModifyMembers',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.ModifyMembersRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.ModifyMembersResponse.FromString,
        )
    self.GetGroups = channel.unary_unary(
        '/auth_1_10.API/GetGroups',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetGroupsRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetGroupsResponse.FromString,
        )
    self.GetUsers = channel.unary_unary(
        '/auth_1_10.API/GetUsers',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetUsersRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetUsersResponse.FromString,
        )
    self.GetOneTimePassword = channel.unary_unary(
        '/auth_1_10.API/GetOneTimePassword',
        request_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetOneTimePasswordRequest.SerializeToString,
        response_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetOneTimePasswordResponse.FromString,
        )


class APIServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Activate(self, request, context):
    """Activate/Deactivate the auth API. 'Activate' sets an initial set of admins
    for the Pachyderm cluster, and 'Deactivate' removes all ACLs, tokens, and
    admins from the Pachyderm cluster, making all data publicly accessable
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Deactivate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetConfiguration(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetConfiguration(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetAdmins(self, request, context):
    """GetAdmins returns the current list of cluster admins
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ModifyAdmins(self, request, context):
    """ModifyAdmins adds or removes admins from the cluster
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Authenticate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Authorize(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def WhoAmI(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetScope(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetScope(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetACL(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetACL(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetAuthToken(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ExtendAuthToken(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RevokeAuthToken(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetGroupsForUser(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ModifyMembers(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetGroups(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetUsers(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetOneTimePassword(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_APIServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Activate': grpc.unary_unary_rpc_method_handler(
          servicer.Activate,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.ActivateRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.ActivateResponse.SerializeToString,
      ),
      'Deactivate': grpc.unary_unary_rpc_method_handler(
          servicer.Deactivate,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.DeactivateRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.DeactivateResponse.SerializeToString,
      ),
      'GetConfiguration': grpc.unary_unary_rpc_method_handler(
          servicer.GetConfiguration,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetConfigurationRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetConfigurationResponse.SerializeToString,
      ),
      'SetConfiguration': grpc.unary_unary_rpc_method_handler(
          servicer.SetConfiguration,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.SetConfigurationRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.SetConfigurationResponse.SerializeToString,
      ),
      'GetAdmins': grpc.unary_unary_rpc_method_handler(
          servicer.GetAdmins,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetAdminsRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetAdminsResponse.SerializeToString,
      ),
      'ModifyAdmins': grpc.unary_unary_rpc_method_handler(
          servicer.ModifyAdmins,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.ModifyAdminsRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.ModifyAdminsResponse.SerializeToString,
      ),
      'Authenticate': grpc.unary_unary_rpc_method_handler(
          servicer.Authenticate,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.AuthenticateRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.AuthenticateResponse.SerializeToString,
      ),
      'Authorize': grpc.unary_unary_rpc_method_handler(
          servicer.Authorize,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.AuthorizeRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.AuthorizeResponse.SerializeToString,
      ),
      'WhoAmI': grpc.unary_unary_rpc_method_handler(
          servicer.WhoAmI,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.WhoAmIRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.WhoAmIResponse.SerializeToString,
      ),
      'GetScope': grpc.unary_unary_rpc_method_handler(
          servicer.GetScope,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetScopeRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetScopeResponse.SerializeToString,
      ),
      'SetScope': grpc.unary_unary_rpc_method_handler(
          servicer.SetScope,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.SetScopeRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.SetScopeResponse.SerializeToString,
      ),
      'GetACL': grpc.unary_unary_rpc_method_handler(
          servicer.GetACL,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetACLRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetACLResponse.SerializeToString,
      ),
      'SetACL': grpc.unary_unary_rpc_method_handler(
          servicer.SetACL,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.SetACLRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.SetACLResponse.SerializeToString,
      ),
      'GetAuthToken': grpc.unary_unary_rpc_method_handler(
          servicer.GetAuthToken,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetAuthTokenRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetAuthTokenResponse.SerializeToString,
      ),
      'ExtendAuthToken': grpc.unary_unary_rpc_method_handler(
          servicer.ExtendAuthToken,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.ExtendAuthTokenRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.ExtendAuthTokenResponse.SerializeToString,
      ),
      'RevokeAuthToken': grpc.unary_unary_rpc_method_handler(
          servicer.RevokeAuthToken,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.RevokeAuthTokenRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.RevokeAuthTokenResponse.SerializeToString,
      ),
      'SetGroupsForUser': grpc.unary_unary_rpc_method_handler(
          servicer.SetGroupsForUser,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.SetGroupsForUserRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.SetGroupsForUserResponse.SerializeToString,
      ),
      'ModifyMembers': grpc.unary_unary_rpc_method_handler(
          servicer.ModifyMembers,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.ModifyMembersRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.ModifyMembersResponse.SerializeToString,
      ),
      'GetGroups': grpc.unary_unary_rpc_method_handler(
          servicer.GetGroups,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetGroupsRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetGroupsResponse.SerializeToString,
      ),
      'GetUsers': grpc.unary_unary_rpc_method_handler(
          servicer.GetUsers,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetUsersRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetUsersResponse.SerializeToString,
      ),
      'GetOneTimePassword': grpc.unary_unary_rpc_method_handler(
          servicer.GetOneTimePassword,
          request_deserializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetOneTimePasswordRequest.FromString,
          response_serializer=client_dot_admin_dot_v1__10_dot_auth_dot_auth__pb2.GetOneTimePasswordResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'auth_1_10.API', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
